@@ -248,8 +248,8 @@ def get_json_ads_number(json_input, customer_name, customer_type):
     return len(json_input[customer_name.lower() + '_' + customer_type.lower()])
 
 
-def get_json_ad_status(json_input, customer_name, customer_type, index):
-    return 1
+def get_json_ad_status(json_input, index):
+    return json_input[index]['Status']
 
 
 def get_json_ad_photos(json_input, customer_name, customer_type, index):
@@ -337,17 +337,23 @@ def get_counter_of_last_four_months(customer, customer_type):
 
     #====================utilisation_per_periode
 
-
     last_date_in_last_month = first - datetime.timedelta(days=1)
     if str(calendar.monthrange(int(today.strftime("%Y")), int(today.strftime("%m")))[1]) == today.strftime("%d"):
         last_month_day = calendar.monthrange(int(last_date_in_last_month.strftime("%Y")), int(last_date_in_last_month.strftime("%m")))[1]
         try:
-            current_day_in_the_last_month = today.replace(day=last_month_day).replace(
+            if int(today.strftime("%m")) - 1 == 2:
+                current_day_in_the_last_month = today.replace(day=28, month=int(last_date_in_last_month.strftime("%m")))
+            else:
+                current_day_in_the_last_month = today.replace(day=last_month_day).replace(
                 month=int(last_date_in_last_month.strftime("%m")))
+
         except Exception as e:
             current_day_in_the_last_month = today.replace(month=int(last_date_in_last_month.strftime("%m"))).replace(day=last_month_day)
     else:
-        current_day_in_the_last_month = today.replace(month=int(last_date_in_last_month.strftime("%m")))
+        if int(today.strftime("%m")) - 1 == 2:
+            current_day_in_the_last_month = today.replace(day=28, month=int(last_date_in_last_month.strftime("%m")))
+        else:
+            current_day_in_the_last_month = today.replace(month=int(last_date_in_last_month.strftime("%m")))
 
     utilisation_per_period = db.get_similars_request_period(HISTORY_SEARCH_TABLE, customer, customer_type, str(first),
                                                             str(today))
